Index: src/interpreter/bytecodes.h |
diff --git a/src/interpreter/bytecodes.h b/src/interpreter/bytecodes.h |
index a5b34f791afcfa1ca7101a4333e9dcd34a3b8403..e5097b4183a5c5f19f1d112bebf7557064dde0a1 100644 |
--- a/src/interpreter/bytecodes.h |
+++ b/src/interpreter/bytecodes.h |
@@ -23,30 +23,34 @@ namespace interpreter { |
V(Reg) |
// The list of bytecodes which are interpreted by the interpreter. |
-#define BYTECODE_LIST(V) \ |
- \ |
- /* Loading the accumulator */ \ |
- V(LdaZero, OperandType::kNone) \ |
- V(LdaSmi8, OperandType::kImm8) \ |
- V(LdaConstant, OperandType::kIdx) \ |
- V(LdaUndefined, OperandType::kNone) \ |
- V(LdaNull, OperandType::kNone) \ |
- V(LdaTheHole, OperandType::kNone) \ |
- V(LdaTrue, OperandType::kNone) \ |
- V(LdaFalse, OperandType::kNone) \ |
- \ |
- /* Register-accumulator transfers */ \ |
- V(Ldar, OperandType::kReg) \ |
- V(Star, OperandType::kReg) \ |
- \ |
- /* Binary Operators */ \ |
- V(Add, OperandType::kReg) \ |
- V(Sub, OperandType::kReg) \ |
- V(Mul, OperandType::kReg) \ |
- V(Div, OperandType::kReg) \ |
- V(Mod, OperandType::kReg) \ |
- \ |
- /* Control Flow */ \ |
+#define BYTECODE_LIST(V) \ |
+ \ |
+ /* Loading the accumulator */ \ |
+ V(LdaZero, OperandType::kNone) \ |
+ V(LdaSmi8, OperandType::kImm8) \ |
+ V(LdaConstant, OperandType::kIdx) \ |
+ V(LdaUndefined, OperandType::kNone) \ |
+ V(LdaNull, OperandType::kNone) \ |
+ V(LdaTheHole, OperandType::kNone) \ |
+ V(LdaTrue, OperandType::kNone) \ |
+ V(LdaFalse, OperandType::kNone) \ |
+ \ |
+ /* Register-accumulator transfers */ \ |
+ V(Ldar, OperandType::kReg) \ |
+ V(Star, OperandType::kReg) \ |
+ \ |
+ /* LoadIC operations */ \ |
+ V(LoadIC, OperandType::kReg, OperandType::kIdx) \ |
+ V(KeyedLoadIC, OperandType::kReg, OperandType::kIdx) \ |
+ \ |
+ /* Binary Operators */ \ |
+ V(Add, OperandType::kReg) \ |
+ V(Sub, OperandType::kReg) \ |
+ V(Mul, OperandType::kReg) \ |
+ V(Div, OperandType::kReg) \ |
+ V(Mod, OperandType::kReg) \ |
+ \ |
+ /* Control Flow */ \ |
V(Return, OperandType::kNone) |